Package: netgwas
Type: Package
Title: Network-Based Genome Wide Association Studies
Version: 1.14.5
Authors@R: c(person(given = "Pariya",
           family = "Behrouzi",
           role = c("aut", "cre"),
           email = "pariya.behrouzi@gmail.com", comment = c(ORCID = "0000-0001-6762-5433")), person(given = "Ernst", family = "C. Wit", role = "ctb"))
Depends: R (>= 3.1.0)
Imports: Matrix(>= 1.4-1), igraph, qtl, parallel, methods, glasso,
        MASS, huge,tmvtnorm
Suggests: testthat
Description: A multi-core R package that contains a set of tools based on copula graphical
             models for accomplishing the three interrelated goals in genetics and genomics in an
			 unified way: (1) linkage map construction, (2) constructing linkage disequilibrium
			 networks, and (3) exploring high-dimensional genotype-phenotype network and genotype-
			 phenotype-environment interactions networks. 
			 The 'netgwas' package can deal with biparental inbreeding and outbreeding species with
			 any ploidy level, namely diploid (2 sets of chromosomes), triploid (3 sets of chromosomes),
			 tetraploid (4 sets of chromosomes) and so on. We target on high-dimensional data where 
			 number of variables p is considerably larger than number of sample sizes (p >> n). 
			 The computations is memory-optimized using the sparse matrix output. The 'netgwas' 
			 implements the methodological developments in Behrouzi and Wit (2017)
             <doi:10.1111/rssc.12287> and Behrouzi and Wit (2017) <doi:10.1093/bioinformatics/bty777>. 
License: GPL-3
Encoding: UTF-8
Date/Publication: 2026-05-04 12:50:09 UTC
NeedsCompilation: no
Packaged: 2026-05-04 09:36:59 UTC; behro001
Author: Pariya Behrouzi [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-6762-5433>),
  Ernst C. Wit [ctb]
Maintainer: Pariya Behrouzi <pariya.behrouzi@gmail.com>
Repository: CRAN
Built: R 4.6.0; ; 2026-05-04 17:19:45 UTC; unix
