export(simgeno)
export(simRIL)
export(cutoffs)
export(lower.upper)
export(R.gibbs)
export(R.approx)
export(netmap)
export(netsnp)
export(netphenogeno)
export(selectnet)
export(buildMap)
export(cal.pos)
export(detect.err)
export(cross2netgwas)
export(netgwas2cross)

S3method("plot","simgeno")
S3method("print","simgeno")
S3method("plot","netgwas")
S3method("print","netgwas")
S3method("plot","select")
S3method("plot","netgwasmap")
S3method("print","netgwasmap")

import("Matrix", "igraph", "qtl", "parallel")

importFrom( "tmvtnorm", "rtmvnorm.sparseMatrix", "ptmvnorm")
importFrom( "glasso", "glasso")
importFrom( "methods", "as", "new")
importFrom( "grDevices", "gray.colors", "terrain.colors", "rainbow")
importFrom( "graphics", "par", "plot", "legend", "screen", "split.screen", "plot.new", "box", "title")
importFrom( "stats", "cor", "dnorm", "pnorm", "qnorm", "runif", "rnorm", "rchisq", "sd", "rbinom" )
importFrom( "utils", "flush.console")
importFrom( "huge", "huge")
importFrom( "MASS", "sammon")

