\name{netgwas-internal}
\alias{netgwas-internal}
\title{netgwas-internal}

\description{
  Internal netgwas functions. These are not intended to be called by the users.
}

\author{Pariya Behrouzi <pariya.behrouzi@gmail.com> and Ernst C. Wit}

\keyword{internal}
